```{include} ../README.md
```

## Table of contents

```{toctree}
:caption: Getting Started
:maxdepth: 1

install
commonissues
tutorials/quickstart.ipynb
tutorials/precision.ipynb
tutorials/units.ipynb
```

```{toctree}
:caption: Tutorials
:maxdepth: 1

tutorials/about.ipynb
tutorials/transit.ipynb
tutorials/mw_transit.ipynb
tutorials/ttv.ipynb
tutorials/rv.ipynb
tutorials/rossiter.ipynb
```

```{toctree}
:caption: Additional Tutorials
:maxdepth: 1

tutorials/introduction-to-jax.ipynb
tutorials/autodiff.ipynb
tutorials/core-from-scratch.ipynb
```

```{toctree}
:caption: Developer Documentation
:maxdepth: 1

conventions.ipynb
api
contributing

```
